import setuptools


setuptools.setup(
    name="split_types",
    version="0.0.4",
    author="Ben Leong",
    author_email="benleong0@gmail.com",
    description="Shared types",
    long_description="Shared types for Split",
    long_description_content_type="text/markdown",
    url="https://github.com/benleong0/split/split_types",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)